'use strict';

const colors = require('@ant-design/colors');
const tinycolor = require('@ctrl/tinycolor');

function makeRgbaValue(key, slash = true) {
  return slash ? `rgba(var(${key}) / <alpha-value>)` : `rgba(var(${key}),<alpha-value>)`;
}
const gray = {
  1: "#ffffff",
  2: "#fafafa",
  3: "#f5f5f5",
  4: "#f0f0f0",
  5: "#d9d9d9",
  6: "#bfbfbf",
  7: "#8c8c8c",
  8: "#595959",
  9: "#434343",
  10: "#262626",
  11: "#1f1f1f",
  12: "#141414",
  13: "#000000"
};
function generateColors(key, color, opt) {
  let opts = opt;
  if (opts === true) {
    opts = {
      theme: "dark",
      backgroundColor: "#141414"
    };
  }
  const colors$1 = colors.generate(color, opts);
  return {
    [key]: colors$1[5],
    [`${key}-hover`]: colors$1[4],
    [`${key}-active`]: colors$1[6],
    [`${key}-content`]: gray[1]
    //  typeof opts === 'object' && opts.theme === 'dark' ? gray[13] : gray[1]
  };
}
const composeVarsObject = (colorsMap, shareVars, slash = true) => {
  return Object.entries({
    ...colorsMap,
    ...shareVars
  }).reduce((acc, [key, value]) => {
    const k = "--" + key;
    const color = new tinycolor.TinyColor(value);
    let str = value;
    if (color.isValid) {
      if (slash) {
        str = color.a < 1 && color.a > 0 ? `${color.r} ${color.g} ${color.b} / ${color.a}` : `${color.r} ${color.g} ${color.b}`;
      } else {
        str = color.a < 1 && color.a > 0 ? `${color.r},${color.g},${color.b},${color.a}` : `${color.r},${color.g},${color.b}`;
      }
    }
    acc[k] = str;
    return acc;
  }, {});
};

exports.generate = colors.generate;
exports.presetPrimaryColors = colors.presetPrimaryColors;
exports.TinyColor = tinycolor.TinyColor;
exports.composeVarsObject = composeVarsObject;
exports.generateColors = generateColors;
exports.gray = gray;
exports.makeRgbaValue = makeRgbaValue;
